# 介绍
#### 名字
> ZhenZhe Gao
#### 邮箱
> 2983536011@qq.com
# 注意
lglib.init.progressbar
<br>lglib.init.hide_cursor
<br>lglib.init.show_cursor
<br>lglib.file.recording
<br> <span style="color:red">not from the author himself / 不是来自作者本人<br>
The author only modifies part of the code for use / 作者仅修改部分代码提供使用</span>